@@ -7,7 +7,7 @@ use warnings;
 use autodie;
 use namespace::autoclean;
 
-our $VERSION = '1.11';
+our $VERSION = '1.12';
 
 use Devel::PPPort 3.42;
 use Dist::Zilla 6.0;
@@ -23,7 +23,9 @@ use Dist::Zilla::Plugin::CheckSelfDependency;
 use Dist::Zilla::Plugin::CheckStrictVersion;
 use Dist::Zilla::Plugin::CheckVersionIncrement;
 use Dist::Zilla::Plugin::CopyFilesFromBuild;
+use Dist::Zilla::Plugin::DROLSKY::BundleAuthordep;
 use Dist::Zilla::Plugin::DROLSKY::Contributors;
+use Dist::Zilla::Plugin::DROLSKY::DevTools;
 use Dist::Zilla::Plugin::DROLSKY::License;
 use Dist::Zilla::Plugin::DROLSKY::MakeMaker;
 use Dist::Zilla::Plugin::DROLSKY::PerlLinterConfigFiles;
@@ -280,6 +282,7 @@ sub _build_plugins {
     }
 
     return [
+        'DROLSKY::BundleAuthordep',
         $self->_gather_dir_plugin,
         $self->_basic_plugins,
         $self->_authority_plugin,
@@ -545,6 +548,8 @@ sub _explicit_prereq_plugins {
                 -type          => 'requires',
                 'Perl::Critic' => '1.126',
                 'Perl::Tidy'   => '20160302',
+                'Pod::Checker' => '1.74',
+                'Pod::Tidy'    => '0.10',
             },
         );
     }
@@ -775,12 +780,20 @@ sub _release_check_plugins {
 sub _precious_plugin {
     my $self = shift;
 
+    return if -e 'tidyall.ini';
+
     my %precious_config;
     $precious_config{stopwords_file} = $self->stopwords_file
         if $self->_has_stopwords_file;
 
-    return 'DROLSKY::Precious' unless keys %precious_config;
-    return [ 'DROLSKY::Precious' => \%precious_config ];
+    return (
+        'DROLSKY::DevTools',
+        (
+            keys %precious_config
+            ? [ 'DROLSKY::Precious' => \%precious_config ]
+            : 'DROLSKY::Precious'
+        ),
+    );
 }
 
 sub _git_plugins {
@@ -867,7 +880,7 @@ Dist::Zilla::PluginBundle::DROLSKY - DROLSKY's plugin bundle
 
 =head1 VERSION
 
-version 1.11
+version 1.12
 
 =head1 SYNOPSIS
 
@@ -912,11 +925,15 @@ this directly for your own distributions, but you may find it useful as a
 source of ideas for building your own bundle.
 
 This bundle uses L<Dist::Zilla::Role::PluginBundle::PluginRemover> and
-L<Dist::Zilla::Role::PluginBundle::Config::Slicer> so I can remove or
-configure any plugin as needed.
+L<Dist::Zilla::Role::PluginBundle::Config::Slicer> so I can remove or configure
+any plugin as needed.
 
 This is more or less equivalent to the following F<dist.ini>:
 
+    ; updates the dist.ini to include an authordep on this bundle at its
+    ; current $VERSION.
+    [DROLSKY::BundleAuthordep]
+
     ; Picks one of these - defaults to DROLSKY::MakeMaker
     [DROLSKY::MakeMaker]
     [ModuleBuild]
@@ -1113,6 +1130,8 @@ This is more or less equivalent to the following F<dist.ini>:
     [DROLSKY::PerlLinterConfigFiles]
     ; Generates/updates precious.toml
     [DROLSKY::Precious]
+    ; Generates some dev tool helper scripts when using precious.
+    [DROLSKY::DevTools]
 
     ; The allow_dirty list is basically all of the generated or munged files
     ; in the distro, including:
@@ -1184,7 +1203,7 @@ Mark Fowler <mark@twoshortplanks.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 - 2020 by Dave Rolsky.
+This software is Copyright (c) 2013 - 2021 by Dave Rolsky.
 
 This is free software, licensed under:
 
